==> nextcloud-19.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/settings/l10n/ar.js <==
OC.L10N.register(
    "settings",
    {
    "Migration in progress. Please wait until the migration is finished" : "عملية الترحيل جارية. الرجاء الإنتظار حتى تكتمل العملية",
    "Migration started …" : "بدأت عملية الترحيل …",
    "Saved" : "حفظ",
    "Not saved" : "لم يتم حفظه",
    "Sending…" : "جارٍ الإرسال …",
    "Email sent" : "تم ارسال البريد الالكتروني",
    "Private" : "خاص بك",
    "Public" : "عمومي",
    "Verify" : "تحقق",
    "Verifying …" : "عملية التحقق جارية …",
    "Unable to change password" : "لا يمكن تغيير كلمة المرور",
    "Very weak password" : "كلمة السر ضعيفة جدا",
    "Weak password" : "كلمة السر ضعيفة",
    "Good password" : "كلمة السر جيدة",
    "Strong password" : "كلمة السر قوية",
    "Select a profile picture" : "اختر صورة الملف الشخصي ",
    "Week starts on {fdow}" : "بداية الأسبوع يوم {fdow}",
    "Groups" : "مجموعات",
    "Add link" : "إضافة رابط",
    "Retry" : "أعد المحاولة",
    "{actor} changed your password" : "{actor} قام بتغيير كلمتك السرية",
    "You changed your password" : "لقد قمت بتعديل كلمة مرورك",
    "Your password was reset by an administrator" : "قام أحد المدراء بإعادة تعيين كلمة مرورك",
    "{actor} changed your email address" : "{actor} قام بتغيير عنوان بريدك الإلكتروني",
    "You changed your email address" : "لقد قمت بتعديل عنوان بريدك الإلكتروني",
    "Your email address was changed by an administrator" : "قام أحد المدراء بتغيير عنوان بريدك الإلكتروني",
    "Security" : "الأمان",
    "Couldn't remove app." : "لم نتمكّن مِن حذف التطبيق.",
    "Couldn't update app." : "تعذر تحديث التطبيق.",
    "Wrong password" : "كلمة مرور خاطئة",
    "No user supplied" : "لم يتم توفير مستخدم ",
    "Authentication error" : "لم يتم التأكد من الشخصية بنجاح",
    "Wrong admin recovery password. Please check the password and try again." : "خطا في كلمة مرور المسؤول المستردة, يرجى التاكد من كلمة المرور والمحاولة مرة اخرى.",
    "Federated Cloud Sharing" : "المشاركة السحابية الموحّدة",
    "Invalid SMTP password." : "كلمة مرور SMTP خاطئة.",
    "Email setting test" : "تجريب إعدادات البريد الإلكتروني",
    "Well done, %s!" : "حسنًا فعلت، %s !",
    "Invalid mail address" : "عنوان البريد الإلكتروني خاطئ",
    "Settings saved" : "تم حفظ الإعدادات",
    "Unable to change full name" : "لم يتم التمكن من تغيير اسمك الكامل",
    "Password changed for %s" : "تم تعديل كلمة سر %s",
    "Your %s account was created" : "تم إنشاء حسابك %s",
    "Welcome aboard" : "مرحبًا بكم على متن ناكست كلاود",
    "Welcome aboard %s" : "مرحبًا بكم على متن ناكست كلاود يا %s",
    "Your username is: %s" : "إسم المستخدم الخاص بك هو : %s",
    "Set your password" : "قم بإدخال كلمتك السرية",
    "Go to %s" : "الإنتقال إلى %s",
    "Install Client" : "تنصيب العميل",
    "Additional settings" : "الإعدادات المتقدمة",
    "Overview" : "نظرة شاملة",
    "Basic settings" : "الإعدادات الأساسية",
    "Sharing" : "مشاركة",
    "Personal info" : "المعلومات الشخصية",
    "Mobile & desktop" : "الجوال وسطح المكتب",
    "Create" : "إنشاء",
    "Delete" : "إلغاء",
    "Unlimited" : "غير محدود",
    "Verifying" : "التحقق",
    "Save changes" : "حفظ التعديلات",
    "by" : "من قبل",
    "Update to {version}" : "التحديث إلى {version}",
    "Remove" : "حذف",
    "Disable" : "إيقاف",
    "All" : "الكل",
    "No results" : "دون أية نتيجة",
    "View in store" : "العرض على المتجر",
    "Visit website" : "زر الموقع",
    "Report a bug" : "الإبلاغ عن عِلّة",
    "User documentation" : "دليل المستخدم",
    "Admin documentation" : "دليل المدير",
    "Developer documentation" : "دليل المُطوّر",
    "Results from other categories" : "نتائج عبر الفئات الأخرى",
    "Enable all" : "تنشيط الكل",
    "Enable" : "تفعيل",
    "Device settings" : "إعدادات الجهاز",
    "Allow filesystem access" : "السماح بالنفاذ إلى نظام الملفات",
    "Rename" : "تعديل الإسم",
    "Revoke" : "إلغاء",
    "Internet Explorer" : "إنترنت إكسبلورر",
    "Edge" : "آدج",
    "Firefox" : "فايرفوكس",
    "Google Chrome" : "غوغل كروم",
    "Safari" : "سفاري",
    "Google Chrome for Android" : "غوغل كروم لنظام الأندرويد",
    "iPhone" : "الآيفون",
    "Nextcloud Android app" : "تطبيق Nextcloud للأندرويد",
    "Nextcloud Talk for iOS" : "Nextcloud Talk للآيفون",
    "Nextcloud Talk for Android" : "Nextcloud Talk للأندرويد",
    "This session" : "هذه الجلسة",
    "Device" : "الجهاز",
    "Last activity" : "آخر نشاط",
    "App name" : "إسم التطبيق",
    "Create new app password" : "إنشاء كلمة سرية جديدة للتطبيق",
    "Username" : "إسم المستخدم",
    "Password" : "كلمة المرور",
    "Done" : "تم",
    "Copied!" : "تم نسخه !",
    "Copy" : "نسخ",
    "Delete user" : "احذف المستخدم",
    "Cancel" : "الغاء",
    "Welcome mail sent!" : "تم إرسال بريد الترحيب!",
    "Display name" : "الاسم المعروض",
    "Email" : "البريد الإلكترونى",
    "Default language" : "اللغة الافتراضية",
    "Add a new user" : "إضافة مستخدِم جديد",
    "Close" : "إغلاق",
    "Group admin for" : "فريق المُدراء لـ",
    "Quota" : "حصه",
    "Language" : "اللغة",
    "Storage location" : "مسار التخزين",
    "Last login" : "آخِر تسجيل للدخول",
    "All languages" : "كافة اللغات",
    "Name your device" : "اسم جهازك",
    "Add" : "إضافة",
    "Your browser does not support WebAuthn." : "متصفحك لا يدعم WebAuthn.",
    "Your apps" : "تطبيقاتك",
    "Active apps" : "التطبيقات النشطة",
    "Disabled apps" : "التطبيقات المعطلة",
    "Updates" : "التحديثات",
    "App bundles" : "حُزَم التطبيقات",
    "New user" : "مستخدم جديد",
    "Add group" : "إضافة فريق",
    "Everyone" : "الجميع",
    "Admins" : "المدراء",
    "Disabled users" : "المستخدمون المُعطَّلون",
    "Remove group" : "حذف الفريق",
    "Default quota:" : "الحصة الافتراضية:",
    "Show Languages" : "اعرض اللغات",
    "Never" : "أبدا",
    "App update" : "تحديث التطبيق",
    "Administrator documentation" : "دليل المدير",
    "Documentation" : "الدليل",
    "Forum" : "منتدى",
    "None" : "لا شيء",
    "Login" : "تسجيل الدخول",
    "NT LAN Manager" : "مدير الشبكة المحلية LAN NT",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "خادوم البريد",
    "Open documentation" : "فتح الدليل",
    "Send mode" : "وضعية الإرسال",
    "Encryption" : "التشفير",
    "From address" : "عنوان الإرسال",
    "mail" : "البريد",
    "Authentication method" : "أسلوب التطابق",
    "Authentication required" : "المصادقة لازمة",
    "Server address" : "عنوان الخادم",
    "Port" : "المنفذ",
    "Credentials" : "Credentials",
    "SMTP Username" : "إسم مستخدم الـ SMTP",
    "SMTP Password" : "كلمة مرور الـ SMTP",
    "Save" : "حفظ",
    "Test email settings" : "فحص إعدادات البريد الإلكتروني",
    "Send email" : "إرسال بريد إلكتروني",
    "Security & setup warnings" : "تحذيرات الإعداد و الأمان",
    "Version" : "إصدار",
    "Two-Factor Authentication" : "المصادقة بخطوتين",
    "Server-side encryption" : "التشفير مِن جانب الخادوم",
    "Enable server-side encryption" : "تشغيل التشفير مِن جانب الخادوم",
    "Enable encryption" : "تنشيط التعمية",
    "Start migration" : "إبدأ الترحيل",
    "Background jobs" : "الأنشطة في الخلفية",
    "Execute one task with each page loaded" : "قم بتنفيذ مهمة واحدة مع كل صفحة تم تحميلها",
    "Allow apps to use the Share API" : "السماح للتطبيقات بالمشاركة عن طريق الAPI",
    "Expire after " : "ينتهي بعد",
    "days" : "أيام",
    "Allow users to share via link" : "السماح للمستخدم بمشاركة الملف عن طريق رابط",
    "Allow public uploads" : "السماح بالرفع للعامة ",
    "Always ask for a password" : "أطلب دائما كلمة السر",
    "Allow resharing" : "السماح بإعادة المشاركة ",
    "Personal" : "شخصي",
    "Administration" : "الإدارة",
    "Like our Facebook page" : "قم بالإعجاب بصفحتنا على الفايسبوك",
    "Follow us on Twitter" : "تابعونا على تويتر",
    "Follow us on Mastodon" : "تابعونا على ماستدون",
    "Check out our blog" : "إلقي نظرة على مدوّنتنا",
    "Profile picture" : "صورة الملف الشخصي",
    "Upload new" : "رفع الان",
    "Select from Files" : "إختر مِن بين الملفات",
    "Remove image" : "إزالة الصورة",
    "png or jpg, max. 20 MB" : "نسق png أو jpg و حجم أقصاه 20 م.ب",
    "Choose as profile picture" : "اختر صورة للملف الشخصي ",
    "Details" : "التفاصيل",
    "You are a member of the following groups:" : "إنك عضو في الفِرَق التالية:",
    "You are using <strong>%s</strong>" : "تستخدم حاليا <strong>%s</strong>",
    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "تستخدم حاليا <strong>%1$s</strong> مِن أصل <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
    "Full name" : "الإسم الكامل",
    "No display name set" : "لم يتم إدخال أي إسم",
    "Your email address" : "عنوانك البريدي",
    "No email address set" : "لم يتم إدخال أي عنوان للبريد الإلكتروني",
    "For password reset and notifications" : "لإعادة تعيين كلمة السر و تلقي الإشعارات",
    "Phone number" : "رقم الهاتف",
    "Your phone number" : "رقم هاتفك",
    "Address" : "العنوان",
    "Your postal address" : "عنوان البريد العادي",
    "Website" : "موقع الويب",
    "Link https://…" : "الرابط https://…",
    "Twitter" : "تويتر",
    "Twitter handle @…" : "حساب تويتر @…",
    "Help translate" : "ساعد في الترجمه",
    "Current password" : "كلمات السر الحالية",
    "New password" : "كلمات سر جديدة",
    "Change password" : "عدل كلمة السر",
    "Share" : "شارك",
    "Valid until {date}" : "صالح إلى غاية {date}",
    "Local" : "المحلي",
    "Only visible to local users" : "ظاهر فقط للمستخدِمين المحليين",
    "Only visible to you" : "ظاهر فقط بالنسبة لك",
    "Contacts" : "جهات الإتصال",
    "Visible to local users and to trusted servers" : "ظاهر فقط للمستخدمين المحليين و للخوادم الموثوق فيها",
    "Arabic (Algeria)" : "العربية (الجزائر)",
    "Arabic (Bahrain)" : "العربية (البحرين)",
    "Arabic (Egypt)" : "العربية (مصر)",
    "Arabic (Iraq)" : "العربية (العراق)",
    "Arabic (Jordan)" : "العربية (الأردن)",
    "Arabic (Kuwait)" : "العربية (الكويت)",
    "Arabic (Lebanon)" : "العربية (لبنان)",
    "Arabic (Libya)" : "العربية (ليبيا)",
    "Arabic (Morocco)" : "العربية (المغرب)",
    "Arabic (Oman)" : "العربية (عمان)",
    "Arabic (Qatar)" : "العربية (قطر)",
    "Arabic (Sudan)" : "العربية (السودان)",
    "Arabic (Syria)" : "العربية (سوريا)",
    "Arabic (Tunisia)" : "العربية (تونس)",
    "Arabic (Yemen)" : "العربية (اليمن)",
    "Arabic" : "العربية",
    "Basque" : "الباسكية",
    "Bulgarian" : "البلغارية",
    "Catalan" : "الكتالونية",
    "Central Morocco Tamazight (Latin)" : "الأمازيغية لوسط المغرب (لاتينية)",
    "Central Morocco Tamazight (Latin, Morocco)" : "الأمازيغية لوسط المغرب (لاتينية، المغرب)",
    "Central Morocco Tamazight" : "الأمازيغية لوسط المغرب",
    "Chinese" : "الصينية",
    "Dutch" : "الهولندية",
    "English" : "الإنجليزية",
    "French (Benin)" : "الفرنسية (البنين)",
    "French (Chad)" : "الفرنسية (تشاد)",
    "French (France)" : "الفرنسية (فرنسا)",
    "French (Mali)" : "الفرنسية (مالي)",
    "French (Niger)" : "الفرنسية (النيجر)",
    "French (Senegal)" : "الفرنسية (السنغال)",
    "French" : "الفرنسية",
    "German (Germany)" : "الألمانية (ألمانيا)",
    "German" : "الألمانية",
    "Hindi (India)" : "الهندية (الهند)",
    "Hindi" : "الهندية",
    "Indonesian" : "الأندونيسية",
    "Italian (Italy)" : "الإيطالية (إيطاليا)",
    "Japanese" : "اليابانية",
    "Kabyle (Algeria)" : "القبائلية (الجزائر)",
    "Kabyle" : "القبائلية",
    "Lithuanian" : "الليثوانية",
    "Persian" : "الفارسية",
    "Russian" : "الروسية",
    "Spanish" : "الإسبانية",
    "Tachelhit" : "تاشلحيت",
    "Zulu" : "الزولو",
    "Official" : "رسمي",
    "SSL Root Certificates" : "شهادات أمان الـ SSL الجذرية",
    "Common Name" : "الإسم الشائع",
    "Valid until" : "صالح حتى",
    "Issued By" : "سُلّمت مِن طرف",
    "Valid until %s" : "صالحة إلى غاية %s",
    "Import root certificate" : "إستيراد شهادة جذرية",
    "Set default expiration date" : "تعيين تاريخ إنتهاء الصلاحية الإفتراضية"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");

==> nextcloud-20.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/settings/l10n/ar.js <==
OC.L10N.register(
    "settings",
    {
    "Migration in progress. Please wait until the migration is finished" : "عملية الترحيل جارية. الرجاء الإنتظار حتى تكتمل العملية",
    "Migration started …" : "بدأت عملية الترحيل …",
    "Saved" : "حفظ",
    "Not saved" : "لم يتم حفظه",
    "Sending…" : "جارٍ الإرسال …",
    "Email sent" : "تم ارسال البريد الالكتروني",
    "Private" : "خاص بك",
    "Public" : "عمومي",
    "Verify" : "تحقق",
    "Verifying …" : "عملية التحقق جارية …",
    "Unable to change password" : "لا يمكن تغيير كلمة المرور",
    "Very weak password" : "كلمة السر ضعيفة جدا",
    "Weak password" : "كلمة السر ضعيفة",
    "Good password" : "كلمة السر جيدة",
    "Strong password" : "كلمة السر قوية",
    "Select a profile picture" : "اختر صورة الملف الشخصي ",
    "Week starts on {fdow}" : "بداية الأسبوع يوم {fdow}",
    "Groups" : "مجموعات",
    "{actor} changed your password" : "{actor} قام بتغيير كلمتك السرية",
    "You changed your password" : "لقد قمت بتعديل كلمة مرورك",
    "Your password was reset by an administrator" : "قام أحد المدراء بإعادة تعيين كلمة مرورك",
    "{actor} changed your email address" : "{actor} قام بتغيير عنوان بريدك الإلكتروني",
    "You changed your email address" : "لقد قمت بتعديل عنوان بريدك الإلكتروني",
    "Your email address was changed by an administrator" : "قام أحد المدراء بتغيير عنوان بريدك الإلكتروني",
    "Security" : "الأمان",
    "Couldn't remove app." : "لم نتمكّن مِن حذف التطبيق.",
    "Couldn't update app." : "تعذر تحديث التطبيق.",
    "Wrong password" : "كلمة مرور خاطئة",
    "No user supplied" : "لم يتم توفير مستخدم ",
    "Authentication error" : "لم يتم التأكد من الشخصية بنجاح",
    "Wrong admin recovery password. Please check the password and try again." : "خطا في كلمة مرور المسؤول المستردة, يرجى التاكد من كلمة المرور والمحاولة مرة اخرى.",
    "Federated Cloud Sharing" : "المشاركة السحابية الموحّدة",
    "Invalid SMTP password." : "كلمة مرور SMTP خاطئة.",
    "Email setting test" : "تجريب إعدادات البريد الإلكتروني",
    "Well done, %s!" : "حسنًا فعلت، %s !",
    "Invalid mail address" : "عنوان البريد الإلكتروني خاطئ",
    "Settings saved" : "تم حفظ الإعدادات",
    "Unable to change full name" : "لم يتم التمكن من تغيير اسمك الكامل",
    "Password changed for %s" : "تم تعديل كلمة سر %s",
    "Your %s account was created" : "تم إنشاء حسابك %s",
    "Welcome aboard" : "مرحبًا بكم على متن ناكست كلاود",
    "Welcome aboard %s" : "مرحبًا بكم على متن ناكست كلاود يا %s",
    "Your username is: %s" : "إسم المستخدم الخاص بك هو : %s",
    "Set your password" : "قم بإدخال كلمتك السرية",
    "Go to %s" : "الإنتقال إلى %s",
    "Install Client" : "تنصيب العميل",
    "Apps" : "التطبيقات",
    "Settings" : "الإعدادات",
    "Personal" : "شخصي",
    "Administration" : "الإدارة",
    "Additional settings" : "الإعدادات المتقدمة",
    "Overview" : "نظرة شاملة",
    "Basic settings" : "الإعدادات الأساسية",
    "Sharing" : "مشاركة",
    "Personal info" : "المعلومات الشخصية",
    "Mobile & desktop" : "الجوال وسطح المكتب",
    "Create" : "إنشاء",
    "Delete" : "إلغاء",
    "Unlimited" : "غير محدود",
    "Verifying" : "التحقق",
    "Save changes" : "حفظ التعديلات",
    "All" : "الكل",
    "No results" : "دون أية نتيجة",
    "Update to {version}" : "التحديث إلى {version}",
    "Remove" : "حذف",
    "Disable" : "إيقاف",
    "View in store" : "العرض على المتجر",
    "Visit website" : "زر الموقع",
    "Report a bug" : "الإبلاغ عن عِلّة",
    "User documentation" : "دليل المستخدم",
    "Admin documentation" : "دليل المدير",
    "Developer documentation" : "دليل المُطوّر",
    "Results from other categories" : "نتائج عبر الفئات الأخرى",
    "Enable all" : "تنشيط الكل",
    "Device settings" : "إعدادات الجهاز",
    "Allow filesystem access" : "السماح بالنفاذ إلى نظام الملفات",
    "Rename" : "تعديل الإسم",
    "Revoke" : "إلغاء",
    "Internet Explorer" : "إنترنت إكسبلورر",
    "Edge" : "آدج",
    "Firefox" : "فايرفوكس",
    "Google Chrome" : "غوغل كروم",
    "Safari" : "سفاري",
    "Google Chrome for Android" : "غوغل كروم لنظام الأندرويد",
    "iPhone" : "الآيفون",
    "Nextcloud Android app" : "تطبيق Nextcloud للأندرويد",
    "Nextcloud Talk for iOS" : "Nextcloud Talk للآيفون",
    "Nextcloud Talk for Android" : "Nextcloud Talk للأندرويد",
    "This session" : "هذه الجلسة",
    "Device" : "الجهاز",
    "Last activity" : "آخر نشاط",
    "App name" : "إسم التطبيق",
    "Create new app password" : "إنشاء كلمة سرية جديدة للتطبيق",
    "Username" : "إسم المستخدم",
    "Password" : "كلمة المرور",
    "Done" : "تم",
    "Copied!" : "تم نسخه !",
    "Copy" : "نسخ",
    "Delete user" : "احذف المستخدم",
    "Cancel" : "الغاء",
    "Welcome mail sent!" : "تم إرسال بريد الترحيب!",
    "Display name" : "الاسم المعروض",
    "Email" : "البريد الإلكترونى",
    "Default language" : "اللغة الافتراضية",
    "Add a new user" : "إضافة مستخدِم جديد",
    "Close" : "إغلاق",
    "Group admin for" : "فريق المُدراء لـ",
    "Quota" : "حصه",
    "Language" : "اللغة",
    "Storage location" : "مسار التخزين",
    "Last login" : "آخِر تسجيل للدخول",
    "All languages" : "كافة اللغات",
    "Name your device" : "اسم جهازك",
    "Add" : "إضافة",
    "Your browser does not support WebAuthn." : "متصفحك لا يدعم WebAuthn.",
    "Your apps" : "تطبيقاتك",
    "Active apps" : "التطبيقات النشطة",
    "Disabled apps" : "التطبيقات المعطلة",
    "Updates" : "التحديثات",
    "App bundles" : "حُزَم التطبيقات",
    "Details" : "التفاصيل",
    "Changelog" : "سجل التغييرات",
    "New user" : "مستخدم جديد",
    "Add group" : "إضافة فريق",
    "Everyone" : "الجميع",
    "Admins" : "المدراء",
    "Disabled users" : "المستخدمون المُعطَّلون",
    "Remove group" : "حذف الفريق",
    "Default quota:" : "الحصة الافتراضية:",
    "Show Languages" : "اعرض اللغات",
    "Enable" : "تفعيل",
    "Never" : "أبدا",
    "App update" : "تحديث التطبيق",
    "Administrator documentation" : "دليل المدير",
    "Documentation" : "الدليل",
    "Forum" : "منتدى",
    "None" : "لا شيء",
    "Login" : "تسجيل الدخول",
    "NT LAN Manager" : "مدير الشبكة المحلية LAN NT",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "خادوم البريد",
    "Open documentation" : "فتح الدليل",
    "Send mode" : "وضعية الإرسال",
    "Encryption" : "التشفير",
    "From address" : "عنوان الإرسال",
    "mail" : "البريد",
    "Authentication method" : "أسلوب التطابق",
    "Authentication required" : "المصادقة لازمة",
    "Server address" : "عنوان الخادم",
    "Port" : "المنفذ",
    "Credentials" : "Credentials",
    "SMTP Username" : "إسم مستخدم الـ SMTP",
    "SMTP Password" : "كلمة مرور الـ SMTP",
    "Save" : "حفظ",
    "Test email settings" : "فحص إعدادات البريد الإلكتروني",
    "Send email" : "إرسال بريد إلكتروني",
    "Security & setup warnings" : "تحذيرات الإعداد و الأمان",
    "Version" : "إصدار",
    "Two-Factor Authentication" : "المصادقة بخطوتين",
    "Server-side encryption" : "التشفير مِن جانب الخادوم",
    "Enable server-side encryption" : "تشغيل التشفير مِن جانب الخادوم",
    "Enable encryption" : "تنشيط التعمية",
    "Start migration" : "إبدأ الترحيل",
    "Background jobs" : "الأنشطة في الخلفية",
    "Allow apps to use the Share API" : "السماح للتطبيقات بالمشاركة عن طريق الAPI",
    "Expire after " : "ينتهي بعد",
    "days" : "أيام",
    "Allow users to share via link" : "السماح للمستخدم بمشاركة الملف عن طريق رابط",
    "Allow public uploads" : "السماح بالرفع للعامة ",
    "Always ask for a password" : "أطلب دائما كلمة السر",
    "Enforce password protection" : "فرض الحماية بكلمة مرور",
    "Allow resharing" : "السماح بإعادة المشاركة ",
    "Like our Facebook page" : "قم بالإعجاب بصفحتنا على الفايسبوك",
    "Follow us on Twitter" : "تابعونا على تويتر",
    "Follow us on Mastodon" : "تابعونا على ماستدون",
    "Check out our blog" : "إلقي نظرة على مدوّنتنا",
    "Profile picture" : "صورة الملف الشخصي",
    "Upload new" : "رفع الان",
    "Select from Files" : "إختر مِن بين الملفات",
    "Remove image" : "إزالة الصورة",
    "png or jpg, max. 20 MB" : "نسق png أو jpg و حجم أقصاه 20 م.ب",
    "Choose as profile picture" : "اختر صورة للملف الشخصي ",
    "You are a member of the following groups:" : "إنك عضو في الفِرَق التالية:",
    "You are using <strong>%s</strong>" : "تستخدم حاليا <strong>%s</strong>",
    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "تستخدم حاليا <strong>%1$s</strong> مِن أصل <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
    "Full name" : "الإسم الكامل",
    "No display name set" : "لم يتم إدخال أي إسم",
    "Your email address" : "عنوانك البريدي",
    "No email address set" : "لم يتم إدخال أي عنوان للبريد الإلكتروني",
    "For password reset and notifications" : "لإعادة تعيين كلمة السر و تلقي الإشعارات",
    "Phone number" : "رقم الهاتف",
    "Your phone number" : "رقم هاتفك",
    "Address" : "العنوان",
    "Your postal address" : "عنوان البريد العادي",
    "Website" : "موقع الويب",
    "Link https://…" : "الرابط https://…",
    "Twitter" : "تويتر",
    "Twitter handle @…" : "حساب تويتر @…",
    "Help translate" : "ساعد في الترجمة",
    "Current password" : "كلمات السر الحالية",
    "New password" : "كلمات سر جديدة",
    "Change password" : "عدل كلمة السر",
    "Valid until {date}" : "صالح إلى غاية {date}",
    "Local" : "المحلي",
    "Only visible to local users" : "ظاهر فقط للمستخدِمين المحليين",
    "Only visible to you" : "ظاهر فقط بالنسبة لك",
    "Contacts" : "جهات الإتصال",
    "Visible to local users and to trusted servers" : "ظاهر فقط للمستخدمين المحليين و للخوادم الموثوق فيها",
    "by" : "من قبل",
    "SSL Root Certificates" : "شهادات أمان الـ SSL الجذرية",
    "Common Name" : "الإسم الشائع",
    "Valid until" : "صالح حتى",
    "Issued By" : "سُلّمت مِن طرف",
    "Valid until %s" : "صالحة إلى غاية %s",
    "Import root certificate" : "إستيراد شهادة جذرية",
    "Execute one task with each page loaded" : "قم بتنفيذ مهمة واحدة مع كل صفحة تم تحميلها"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
